@@ -661,7 +661,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria());
+        $users      = $repository->matching(Criteria::create(true));
 
         self::assertCount(4, $users);
     }
@@ -672,7 +672,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->eq('username', 'beberlei'),
         ));
 
@@ -685,7 +685,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->neq('username', 'beberlei'),
         ));
 
@@ -698,7 +698,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->in('username', ['beberlei', 'gblanco']),
         ));
 
@@ -711,7 +711,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->notIn('username', ['beberlei', 'gblanco', 'asm89']),
         ));
 
@@ -724,7 +724,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $firstUserId = $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->lt('id', $firstUserId + 1),
         ));
 
@@ -737,7 +737,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $firstUserId = $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->lte('id', $firstUserId + 1),
         ));
 
@@ -750,7 +750,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $firstUserId = $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->gt('id', $firstUserId),
         ));
 
@@ -763,7 +763,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $firstUserId = $this->loadFixture();
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $users      = $repository->matching(new Criteria(
+        $users      = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->gte('id', $firstUserId),
         ));
 
@@ -777,7 +777,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
 
         $user = $this->_em->find(CmsUser::class, $userId);
 
-        $criteria = new Criteria(
+        $criteria = Criteria::create(true)->where(
             Criteria::expr()->eq('user', $user),
         );
 
@@ -798,7 +798,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
 
         $user = $this->_em->find(CmsUser::class, $userId);
 
-        $criteria = new Criteria(
+        $criteria = Criteria::create(true)->where(
             Criteria::expr()->in('user', [$user]),
         );
 
@@ -818,13 +818,13 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
 
         $repository = $this->_em->getRepository(CmsUser::class);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->contains('name', 'Foobar')));
+        $users = $repository->matching(Criteria::create(true)->where(Criteria::expr()->contains('name', 'Foobar')));
         self::assertCount(0, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->contains('name', 'Rom')));
+        $users = $repository->matching(Criteria::create(true)->where(Criteria::expr()->contains('name', 'Rom')));
         self::assertCount(1, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->contains('status', 'dev')));
+        $users = $repository->matching(Criteria::create(true)->where(Criteria::expr()->contains('status', 'dev')));
         self::assertCount(2, $users);
     }
 
@@ -834,13 +834,19 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
 
         $repository = $this->_em->getRepository(CmsUser::class);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->startsWith('name', 'Foo')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->startsWith('name', 'Foo'),
+        ));
         self::assertCount(0, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->startsWith('name', 'R')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->startsWith('name', 'R'),
+        ));
         self::assertCount(1, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->startsWith('status', 'de')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->startsWith('status', 'de'),
+        ));
         self::assertCount(2, $users);
     }
 
@@ -850,13 +856,19 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
 
         $repository = $this->_em->getRepository(CmsUser::class);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->endsWith('name', 'foo')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->endsWith('name', 'foo'),
+        ));
         self::assertCount(0, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->endsWith('name', 'oman')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->endsWith('name', 'oman'),
+        ));
         self::assertCount(1, $users);
 
-        $users = $repository->matching(new Criteria(Criteria::expr()->endsWith('status', 'ev')));
+        $users = $repository->matching(Criteria::create(true)->where(
+            Criteria::expr()->endsWith('status', 'ev'),
+        ));
         self::assertCount(2, $users);
     }
 
@@ -866,8 +878,8 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $fixtures       = $this->loadFixtureUserEmail();
         $user           = $this->_em->find(CmsUser::class, $fixtures[0]->id);
         $repository     = $this->_em->getRepository(CmsUser::class);
-        $criteriaIsNull = Criteria::create()->where(Criteria::expr()->isNull('email'));
-        $criteriaEqNull = Criteria::create()->where(Criteria::expr()->eq('email', null));
+        $criteriaIsNull = Criteria::create(true)->where(Criteria::expr()->isNull('email'));
+        $criteriaEqNull = Criteria::create(true)->where(Criteria::expr()->eq('email', null));
 
         $user->setEmail(null);
         $this->_em->persist($user);
@@ -924,7 +936,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
         $this->expectExceptionMessage('Unrecognized field: ');
 
         $repository = $this->_em->getRepository(CmsUser::class);
-        $result     = $repository->matching(new Criteria(
+        $result     = $repository->matching(Criteria::create(true)->where(
             Criteria::expr()->eq('username = ?; DELETE FROM cms_users; SELECT 1 WHERE 1', 'beberlei'),
         ));
 
