@@ -17,7 +17,6 @@ use Doctrine\Tests\OrmFunctionalTestCase;
 use PHPUnit\Framework\Attributes\Group;
 
 use function assert;
-use function class_exists;
 use function get_class;
 
 /**
@@ -438,7 +437,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $user = $this->_em->find($user::class, $user->id);
 
         $criteria = Criteria::create(true)
-            ->orderBy(['name' => class_exists(Order::class) ? Order::Ascending : Criteria::ASC]);
+            ->orderBy(['name' => Order::Ascending]);
 
         self::assertEquals(
             ['A', 'B', 'C', 'Developers_0'],
@@ -478,7 +477,7 @@ class ManyToManyBasicAssociationTest extends OrmFunctionalTestCase
         $user = $this->_em->find($user::class, $user->id);
 
         $criteria = Criteria::create(true)
-            ->orderBy(['name' => class_exists(Order::class) ? Order::Ascending : Criteria::ASC]);
+            ->orderBy(['name' => Order::Ascending]);
 
         self::assertEquals(
             ['A', 'B', 'C'],
