@@ -6,14 +6,14 @@ namespace Doctrine\Tests\ORM\Mapping;
 
 use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\Mapping\Table;
-use PHPUnit\Framework\Attributes\WithoutErrorHandler;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use PHPUnit\Framework\TestCase;
 
 final class TableMappingTest extends TestCase
 {
     use VerifyDeprecations;
 
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testDeprecationOnIndexesPropertyIsTriggered(): void
     {
         $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/11357');
@@ -21,7 +21,7 @@ final class TableMappingTest extends TestCase
         new Table(indexes: []);
     }
 
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testDeprecationOnUniqueConstraintsPropertyIsTriggered(): void
     {
         $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/11357');
