@@ -8,34 +8,34 @@ use Doctrine\ORM\Query;
 use Doctrine\ORM\Query\ParserResult;
 use Doctrine\ORM\Query\SqlWalker;
 use Doctrine\Tests\OrmTestCase;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 /**
  * Tests for {@see \Doctrine\ORM\Query\SqlWalker}
- *
- * @covers \Doctrine\ORM\Query\SqlWalker
  */
+#[CoversClass(SqlWalker::class)]
 class SqlWalkerTest extends OrmTestCase
 {
-    /** @var SqlWalker */
-    private $sqlWalker;
+    private SqlWalker $sqlWalker;
 
     protected function setUp(): void
     {
         $this->sqlWalker = new SqlWalker(new Query($this->getTestEntityManager()), new ParserResult(), []);
     }
 
-    /** @dataProvider getColumnNamesAndSqlAliases */
+    #[DataProvider('getColumnNamesAndSqlAliases')]
     public function testGetSQLTableAlias($tableName, $expectedAlias): void
     {
         self::assertSame($expectedAlias, $this->sqlWalker->getSQLTableAlias($tableName));
     }
 
-    /** @dataProvider getColumnNamesAndSqlAliases */
+    #[DataProvider('getColumnNamesAndSqlAliases')]
     public function testGetSQLTableAliasIsSameForMultipleCalls($tableName): void
     {
         self::assertSame(
             $this->sqlWalker->getSQLTableAlias($tableName),
-            $this->sqlWalker->getSQLTableAlias($tableName)
+            $this->sqlWalker->getSQLTableAlias($tableName),
         );
     }
 
