@@ -15,6 +15,7 @@ use Doctrine\ORM\Cache\DefaultCacheFactory;
 use Doctrine\ORM\Cache\Logging\StatisticsCacheLogger;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\Mapping\Driver\AttributeDriver;
+use Doctrine\Tests\Mocks\AttributeDriverFactory;
 use Doctrine\Tests\Mocks\EntityManagerMock;
 use PHPUnit\Framework\TestCase;
 use Psr\Cache\CacheItemPoolInterface;
@@ -22,7 +23,6 @@ use Symfony\Component\Cache\Adapter\ArrayAdapter;
 
 use function class_exists;
 use function method_exists;
-use function realpath;
 use function sprintf;
 
 // DBAL 3 compatibility
@@ -57,9 +57,10 @@ abstract class OrmTestCase extends TestCase
 
     private CacheItemPoolInterface|null $secondLevelCache = null;
 
+    /** @param list<string> $paths */
     protected function createAttributeDriver(array $paths = []): AttributeDriver
     {
-        return new AttributeDriver($paths);
+        return AttributeDriverFactory::createAttributeDriver($paths);
     }
 
     /**
@@ -96,9 +97,7 @@ abstract class OrmTestCase extends TestCase
         TestUtil::configureProxies($config);
         $config->setMetadataCache($metadataCache);
         $config->setQueryCache(self::getSharedQueryCache());
-        $config->setMetadataDriverImpl(new AttributeDriver([
-            realpath(__DIR__ . '/Models/Cache'),
-        ], true));
+        $config->setMetadataDriverImpl(AttributeDriverFactory::createAttributeDriver([__DIR__ . '/Models/Cache']));
 
         if ($this->isSecondLevelCacheEnabled) {
             $cacheConfig = new CacheConfiguration();
